aboutsummaryrefslogtreecommitdiff
path: root/IkiWiki/Setup.pm
diff options
context:
space:
mode:
Diffstat (limited to 'IkiWiki/Setup.pm')
-rw-r--r--IkiWiki/Setup.pm4
1 files changed, 3 insertions, 1 deletions
diff --git a/IkiWiki/Setup.pm b/IkiWiki/Setup.pm
index 7a7683fab..a3fd5ce66 100644
--- a/IkiWiki/Setup.pm
+++ b/IkiWiki/Setup.pm
@@ -121,9 +121,11 @@ sub getsetup () {
$config{syslog}=$syslog;
return map { sort { $a->[0] cmp $b->[0] } @{$sections{$_}} }
- sort { # core first, then alphabetical
+ sort { # core first, other last, otherwise alphabetical
($b eq "core") <=> ($a eq "core")
||
+ ($a eq "other") <=> ($b eq "other")
+ ||
$a cmp $b
} keys %sections;
}